Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3776)

Unified Diff: chrome/browser/renderer_host/render_widget_host_view_views.h

Issue 7227007: [Mac] Show correct cursor after context menu is closed. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 9 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/renderer_host/render_widget_host_view_views.h
===================================================================
--- chrome/browser/renderer_host/render_widget_host_view_views.h (revision 92355)
+++ chrome/browser/renderer_host/render_widget_host_view_views.h (working copy)
@@ -206,8 +206,8 @@
// The native cursor.
gfx::NativeCursor native_cursor_;
- // Whether we are showing a popup menu.
- bool is_showing_popup_menu_;
+ // Whether we are showing a context menu.
+ bool is_showing_context_menu_;
// The time at which this view started displaying white pixels as a result of
// not having anything to paint (empty backing store from renderer). This

Powered by Google App Engine
This is Rietveld 408576698